@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 use Moo;
 use strictures 2;
@@ -24,7 +24,7 @@ has rtc => (
 );
 
 
-has feedback => (
+has bars => (
     is  => 'rw',
     isa => Num,
     default => sub { 1 },
@@ -60,7 +60,7 @@ sub drums ($self, $dt, $event) {
     my $part = $self->_drum_parts($note);
     my $d = MIDI::Drummer::Tiny->new(
         bpm  => $self->bpm,
-        bars => $self->feedback,
+        bars => $self->bars,
     );
     MIDI::RtMidi::ScorePlayer->new(
       device   => $self->rtc->_midi_out,
@@ -87,7 +87,7 @@ MIDI::RtController::Filter::Drums - RtController drum filters
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -118,12 +118,12 @@ filter for the drums.
 The required L<MIDI::RtController> instance provided in the
 constructor.
 
-=head2 feedback
+=head2 bars
 
-  $feedback = $rtf->feedback;
-  $rtf->feedback($number);
+  $bars = $rtf->bars;
+  $rtf->bars($number);
 
-The feedback (0-127).
+The number of measures to set for the drummer bars.
 
 Default: C<1>
 
